.. naif documentation master file, created by
   sphinx-quickstart on Wed Jan 25 20:22:44 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to naif's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Installation <installation.rst>
   intro.rst
   Tutorials <tutorials.rst>
   API reference <reference.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
